@@ -34,7 +34,7 @@ class LocaleContext(object):
             self.locale = _locales[locale]
         except KeyError:
             try:
-                locale = getattr(__import__("momentpy.i18n.%s" % locale, globals=globals()), locale).Locale()
+                locale = getattr(__import__("i18n.%s" % locale, globals=globals()), locale).Locale()
                 if not isinstance(locale, i18n.BaseLocale):
                     raise ValueError()
                 self.locale = locale
